Returns the job's saved state. It doesn't rebuild the agent, call the model or run tools, so it's safe to use for status displays.
Arguments
- path
Job directory returned by
job_create().
Value
An AgentJob.
Returns the job's saved state. It doesn't rebuild the agent, call the model or run tools, so it's safe to use for status displays.
Job directory returned by job_create().
An AgentJob.