A tool that reads a CSV file and summarises it: row and column counts, column types and the first few rows.
Format
A tool definition created with ellmer::tool().
A tool that reads a CSV file and summarises it: row and column counts, column types and the first few rows.
A tool definition created with ellmer::tool().