Skip to contents

A tool that converts a local document, such as DOCX, PPTX, PDF or HTML, to Markdown with the Python library MarkItDown.

Usage

tool_read_markdown(path)

Format

A tool definition created with ellmer::tool().

Arguments

path

Path to the file to convert.

Value

The Markdown text as one string.

Details

Needs the reticulate package and the Python module markitdown (pip install 'markitdown[all]').

Examples

if (FALSE) { # \dontrun{
tool_read_markdown("report.pdf")
} # }