Creates a permission policy that only allows reading files. All write operations, code execution, and web access are denied.
Value
A Permissions object
Examples
perms <- permissions_readonly()
permissions_check(perms, "read_file", list(path = "test.txt"))
#> <deputy::PermissionResultAllow>
#> @ decision: chr "allow"
#> @ message : NULL