Creates a permission policy suitable for most use cases. Allows reads of files accessible to the R process, confines file writes to the working directory, and permits R code execution. Denies bash commands, web access, and package installation.
Usage
permissions_standard(working_dir = getwd())Value
A Permissions object
Examples
perms <- permissions_standard()
perms$check("write_file", list(path = "output.txt"))
#> $decision
#> [1] "allow"
#>
#> $message
#> NULL
#>
#> attr(,"class")
#> [1] "PermissionResultAllow" "PermissionResult" "list"