Search text files under a directory and return matching lines.
Usage
tool_grep_files(
pattern,
path = ".",
recursive = TRUE,
ignore_case = FALSE,
max_matches = 100
)Format
A tool definition created with ellmer::tool().
Search text files under a directory and return matching lines.
tool_grep_files(
pattern,
path = ".",
recursive = TRUE,
ignore_case = FALSE,
max_matches = 100
)A tool definition created with ellmer::tool().