A tool that applies several exact-text replacements to one file, in order. Each edit follows the rules of tool_edit_file. If any edit fails, the file is left unchanged.
Format
A tool definition created with ellmer::tool().
A tool that applies several exact-text replacements to one file, in order. Each edit follows the rules of tool_edit_file. If any edit fails, the file is left unchanged.
A tool definition created with ellmer::tool().