A tool that reads a file and returns its contents as text. Reading PDFs needs the pdftools package (or the Python module pypdf through reticulate).
Format
A tool definition created with ellmer::tool().
A tool that reads a file and returns its contents as text. Reading PDFs needs the pdftools package (or the Python module pypdf through reticulate).
A tool definition created with ellmer::tool().