A tool that converts a local document, such as DOCX, PPTX, PDF or HTML, to Markdown with the Python library MarkItDown.
Format
A tool definition created with ellmer::tool().
A tool that converts a local document, such as DOCX, PPTX, PDF or HTML, to Markdown with the Python library MarkItDown.
A tool definition created with ellmer::tool().