A tool that writes text to a file, creating the file and any missing parent directories.
Format
A tool definition created with ellmer::tool().
A tool that writes text to a file, creating the file and any missing parent directories.
A tool definition created with ellmer::tool().